==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/plugins/GUITestBase/src/tests/common_scenarios/circular_view/GTTestsCvGeneral.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _GT_TESTS_CV_GENERAL_H_
#define _GT_TESTS_CV_GENERAL_H_

#include <harness/UGUITestBase.h>

namespace U2 {
namespace GUITest_common_scenarios_circular_view {

#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_circular_view"

GUI_TEST_CLASS_DECLARATION(general_avail_1)
GUI_TEST_CLASS_DECLARATION(general_avail_2)
GUI_TEST_CLASS_DECLARATION(general_avail_3)
GUI_TEST_CLASS_DECLARATION(general_avail_4)
GUI_TEST_CLASS_DECLARATION(general_avail_5)
GUI_TEST_CLASS_DECLARATION(general_avail_6)
GUI_TEST_CLASS_DECLARATION(general_avail_7)
GUI_TEST_CLASS_DECLARATION(general_avail_8)

#undef GUI_TEST_SUITE

}  // namespace GUITest_common_scenarios_circular_view
}  // namespace U2

#endif  // _GT_TESTS_CV_GENERAL_H_

==> ugene_49.1+dfsg.orig.tar.xz: ugene-49.1/src/plugins/GUITestBase/src/tests/common_scenarios/circular_view/GTTestsCvGeneral.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#pragma once

#include <harness/UGUITestBase.h>

namespace U2 {
namespace GUITest_common_scenarios_circular_view {

#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_circular_view"

GUI_TEST_CLASS_DECLARATION(general_avail_1)
GUI_TEST_CLASS_DECLARATION(general_avail_2)
GUI_TEST_CLASS_DECLARATION(general_avail_3)
GUI_TEST_CLASS_DECLARATION(general_avail_4)
GUI_TEST_CLASS_DECLARATION(general_avail_5)
GUI_TEST_CLASS_DECLARATION(general_avail_6)
GUI_TEST_CLASS_DECLARATION(general_avail_7)
GUI_TEST_CLASS_DECLARATION(general_avail_8)

#undef GUI_TEST_SUITE

}  // namespace GUITest_common_scenarios_circular_view
}  // namespace U2
